#[repr(transparent)]pub struct XCTIssueType(pub NSInteger);Expand description
Types of failures and other issues that can be reported for tests.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl XCTIssueType
impl XCTIssueType
Sourcepub const AssertionFailure: Self
pub const AssertionFailure: Self
Issue raised by a failed XCTAssert or related API.
Sourcepub const ThrownError: Self
pub const ThrownError: Self
Issue raised by the test throwing an error in Swift. This could also occur if an Objective C test is implemented in the form - (BOOL)testFoo:(NSError **)outError and returns NO with a non-nil out error.
Sourcepub const UncaughtException: Self
pub const UncaughtException: Self
Code in the test throws and does not catch an exception, Objective C, C++, or other.
Sourcepub const PerformanceRegression: Self
pub const PerformanceRegression: Self
One of the XCTestCase(measure:) family of APIs detected a performance regression.
Sourcepub const System: Self
pub const System: Self
One of the framework APIs failed internally. For example, XCUIApplication was unable to launch or terminate an app or XCUIElementQuery was unable to complete a query.
Sourcepub const UnmatchedExpectedFailure: Self
pub const UnmatchedExpectedFailure: Self
Issue raised when XCTExpectFailure is used but no matching issue is recorded.